@@ -1,5 +1,5 @@
 /* cursor.c -- Cursor handling
-   $Id: cursors.c,v 1.17 2000/09/17 12:27:47 john Exp $
+   $Id: cursors.c 4244 2008-08-04 14:42:49Z jkozicki $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -40,9 +40,9 @@ make_bm_cursor (repv image, repv mask, repv fg, repv bg)
     Cursor cursor = 0;
 
     if (rep_STRINGP(fg))
-	fg = Fget_color (fg);
+	fg = Fget_color (fg, Qnil);
     if (rep_STRINGP(bg))
-	bg = Fget_color (bg);
+	bg = Fget_color (bg, Qnil);
 
     if (!rep_STRINGP(image) || !rep_STRINGP(mask)
 	|| !COLORP(fg) || !COLORP(bg))
@@ -147,10 +147,10 @@ recolor-cursor CURSOR FG BG
     XColor xc_fg, xc_bg;
     rep_DECLARE1(cursor, CURSORP);
     if (rep_STRINGP(fg))
-	fg = Fget_color (fg);
+	fg = Fget_color (fg, Qnil);
     rep_DECLARE(2, fg, fg && COLORP(fg));
     if (rep_STRINGP(bg))
-	bg = Fget_color (bg);
+	bg = Fget_color (bg, Qnil);
     rep_DECLARE(3, bg, bg && COLORP(bg));
     xc_fg.red = VCOLOR(fg)->red;
     xc_fg.green = VCOLOR(fg)->green;
@@ -203,7 +203,7 @@ static void
 cursor_prin (repv stream, repv obj)
 {
     char buf[256];
-    sprintf (buf, "#<cursor %x>", (u_int) VCURSOR(obj)->cursor);
+    sprintf (buf, "#<cursor %x>", (unsigned int) VCURSOR(obj)->cursor);
     rep_stream_puts (stream, buf, -1, FALSE);
 }
 
@@ -252,6 +252,8 @@ cursors_init (void)
     rep_ADD_SUBR(Scursorp);
     if (!batch_mode_p ())
 	Fdefault_cursor (Fget_cursor (rep_MAKE_INT (XC_left_ptr)));
+    else
+	default_cursor = Qnil;
     rep_mark_static (&default_cursor);
     rep_INTERN(cursor_shape);
     rep_pop_structure (tem);
