@@ -1,5 +1,5 @@
 /* pixmap-cache.c -- Caching pixmaps
-   $Id: pixmap-cache.c 3297 2000-11-07 00:42:32Z jsh $
+   $Id: pixmap-cache.c 4244 2008-08-04 14:42:49Z jkozicki $
 
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -39,8 +39,8 @@
 
 #include "sawmill.h"
 
-static u_long cached_pixels, max_cached_pixels = 64 * 1024;
-static u_long hits, misses;
+static unsigned long cached_pixels, max_cached_pixels = 64 * 1024;
+static unsigned long hits, misses;
 
 #ifdef NEED_PIXMAP_CACHE
 
