@@ -1,5 +1,5 @@
 /* sawmill_subrs.h -- prototypes
-   $Id: sawmill_subrs.h 4211 2008-01-19 12:03:08Z jkozicki $
+   $Id: sawmill_subrs.h 4251 2008-08-04 20:44:40Z tkorvola $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -106,9 +106,9 @@ extern void events_kill (void);
 /* from fonts.c */
 extern int font_type;
 extern repv Qdefault_font;
-extern int x_text_width (repv font, u_char *string, size_t len);
+extern int x_text_width (repv font, unsigned char *string, size_t len);
 extern void x_draw_string (Window id, repv font, GC gc, Lisp_Color *fg_color,
-			   int x, int y, u_char *string, size_t len);
+			   int x, int y, unsigned char *string, size_t len);
 extern repv Fget_font(repv name);
 extern repv Ffont_get(repv font, repv prop);
 extern repv Ffont_put(repv font, repv prop, repv value);
@@ -216,7 +216,7 @@ extern void paste_image_to_drawable (Lisp_Image *img, Drawable d,
 				     int x, int y, int w, int h);
 extern int image_width (Lisp_Image *im);
 extern int image_height (Lisp_Image *im);
-extern u_char *image_pixels (Lisp_Image *im);
+extern unsigned char *image_pixels (Lisp_Image *im);
 extern int image_row_stride (Lisp_Image *im);
 extern int image_channels (Lisp_Image *im);
 extern void image_changed (Lisp_Image *im);
@@ -318,10 +318,12 @@ extern void remove_window_frame (Lisp_Window *w);
 extern Lisp_Window *add_window (Window id);
 extern void remove_window (Lisp_Window *win, bool destroyed, bool from_error);
 extern void emit_pending_destroys (void);
-extern repv Fwindow_get (repv win, repv prop);
+extern repv Fwindow_get (repv win, repv prop, repv checker);
 extern void register_property_monitor (repv prop, void (*callback)
 				       (Lisp_Window *, repv, repv, repv));
 extern repv Fwindow_put (repv win, repv prop, repv value);
+extern repv Fwindow_remprop (repv win, repv prop);
+extern repv Fwindow_plist (repv win);
 extern repv Fwindow_name (repv win);
 extern repv Fwindow_full_name (repv win);
 extern repv Fwindow_icon_name (repv win);
