@@ -1,6 +1,6 @@
 /* stacking-list.c -- maintain the stacking-ordered window list
 
-   $Id: stacking-list.c 3952 2002-09-22 05:31:34Z jsh $
+   $Id: stacking-list.c 4244 2008-08-04 14:42:49Z jkozicki $
 
    Copyright (C) 2001 Eazel, Inc.
 
@@ -181,7 +181,7 @@ restack_window (Lisp_Window *w)
     if (!WINDOW_IS_GONE_P (w))
     {
 	XWindowChanges wc;
-	u_int mask = 0;
+	unsigned int mask = 0;
 
 	return_if_fail (window_in_stacking_list_p (w));
 
