@@ -1,5 +1,5 @@
 /* windows.c -- window manipulation
-   $Id: windows.c 4223 2008-02-18 19:27:47Z jkozicki $
+   $Id: windows.c 4261 2008-08-05 20:28:11Z tkorvola $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -80,6 +80,7 @@ DEFSYM(south_east, "south-east");
 
 static repv gravity_map[StaticGravity+1];
 
+// In sawfish-1.3.3, the only callback used is keymap_prop_change. 
 struct prop_handler {
     struct prop_handler *next;
     repv prop;
@@ -227,10 +228,10 @@ void
 get_window_protocols (Lisp_Window *w)
 {
     Atom *prot;
-    u_int n;
+    unsigned int n;
     w->does_wm_take_focus = 0;
     w->does_wm_delete_window = 0;
-    if (XGetWMProtocols (dpy, w->id, &prot, &n) != 0)
+    if (XGetWMProtocols (dpy, w->id, &prot, (gpointer) &n) != 0)
     {
 	int i;
 	for (i = 0; i < n; i++)
@@ -366,7 +367,7 @@ text_prop_to_utf8 (XTextProperty *prop)
     {
         char **list;
         int count;
-        prop->nitems = strlen(prop->value);
+        prop->nitems = strlen((gpointer) prop->value);
 #ifdef X_HAVE_UTF8_STRING
         if (Xutf8TextPropertyToTextList (dpy, prop, &list, &count) >= Success)
         {
@@ -428,14 +429,13 @@ get_window_name(Lisp_Window *w)
 Lisp_Window *
 add_window (Window id)
 {
-    char *tem;
     Lisp_Window *w = rep_ALLOC_CELL(sizeof (Lisp_Window));
     if (w != 0)
     {
 	rep_GC_root gc_win;
 	repv win = rep_VAL(w);
 	XWindowChanges xwc;
-	u_int xwcm;
+	unsigned int xwcm;
 	long supplied;
 
 	DB(("add_window (%lx)\n", id));
@@ -485,7 +485,7 @@ add_window (Window id)
 	{
 	    /* Is the window shaped? */
 	    int xws, yws, xbs, ybs;
-	    u_int wws, hws, wbs, hbs;
+	    unsigned int wws, hws, wbs, hbs;
 	    int bounding, clip;
 	    XShapeSelectInput (dpy, w->id, ShapeNotifyMask);
 	    XShapeQueryExtents (dpy, w->id, &bounding, &xws, &yws, &wws, &hws,
@@ -536,7 +536,7 @@ add_window (Window id)
 
 	if (!WINDOW_IS_GONE_P (w))
 	{
-	    repv tem = Fwindow_get (rep_VAL(w), Qplaced);
+           repv tem = Fwindow_get (rep_VAL(w), Qplaced, Qnil);
 	    if (initialising || (tem && tem == Qnil))
 	    {
 		/* ..then the place-window-hook.. */
@@ -639,13 +639,19 @@ emit_pending_destroys (void)
 /* Lisp functions */
 
 DEFUN("window-get", Fwindow_get, Swindow_get,
-      (repv win, repv prop), rep_Subr2) /*
+      (repv win, repv prop, repv checker), rep_Subr3) /*
 ::doc:sawfish.wm.windows.subrs#window-get::
-window-get WINDOW PROPERTY
+window-get WINDOW PROPERTY &optional CHECKER
 
 Return the value of the property named PROPERTY (a symbol) of WINDOW.
 
 Note that these are Lisp properties not X properties.
+
+If the optional argument CHECKER is nil, then the return value is
+nil, either when the property value is nil, or the property is absent.
+
+If CHECKER is non-nil, than it returns CHECKER if the property
+is unset.
 ::end:: */
 {
     repv plist;
@@ -661,7 +667,7 @@ Note that these are Lisp properties not X properties.
 	}
 	plist = rep_CDR(rep_CDR(plist));
     }
-    return Qnil;
+    return checker;
 }
 
 DEFUN("map-window-properties", Fmap_window_properties,
@@ -727,10 +733,10 @@ Note that these are Lisp properties not X properties.
 		if (ph->prop == prop && old != val)
 		    ph->callback (VWIN (win), prop, old, val);
 	    }
-	    rep_CAR(rep_CDR(plist)) = val;
+	    rep_CADR(plist) = val;
 	    return val;
 	}
-	plist = rep_CDR(rep_CDR(plist));
+	plist = rep_CDDR(plist);
     }
     plist = Fcons(prop, Fcons(val, VWIN(win)->plist));
     if (plist != rep_NULL)
@@ -738,6 +744,54 @@ Note that these are Lisp properties not X properties.
     return val;
 }
 
+DEFUN("window-remprop", Fwindow_remprop, Swindow_remprop,
+      (repv win, repv prop), rep_Subr2) /*
+::doc:sawfish.wm.windows.subrs#window-prop-del::
+window-put WINDOW PROPERTY
+
+Delete PROPERTY of WINDOW. Return t for success, nil if WINDOW
+did not have PROPERTY.
+::end:: */
+{
+    repv *pplist;
+    rep_DECLARE1(win, XWINDOWP);
+    pplist = &VWIN(win)->plist;
+    while (rep_CONSP(*pplist) && rep_CONSP(rep_CDR(*pplist)))
+    {
+	if (rep_CAR(*pplist) == prop
+	    || (!rep_SYMBOLP(prop)
+		&& rep_value_cmp (rep_CAR(*pplist), prop) == 0))
+	{
+	    struct prop_handler *ph;
+            repv old = rep_CADR(*pplist);
+            if (old != Qnil)
+                for (ph = prop_handlers; ph != 0; ph = ph->next)
+                    if (ph->prop == prop)
+                        ph->callback(VWIN (win), prop, old, Qnil);
+            *pplist = rep_CDDR(*pplist);
+	    return Qt;
+	}
+	pplist = &rep_CDDR(*pplist);
+    }
+    return Qnil;
+}
+
+DEFUN("window-plist", Fwindow_plist, Swindow_plist,
+      (repv win), rep_Subr1) /*
+::doc:sawfish.wm.windows.subrs#window-plist::
+window-plist WINDOW
+
+Returns the property list of the window window which is of the form
+(prop value prop value ...).
+
+Do not attempt to change properties by modifying the property list in place.
+Use window-put instead.
+::end:: */
+{
+    rep_DECLARE1(win, XWINDOWP);
+    return VWIN(win)->plist;
+}
+
 DEFUN("window-name", Fwindow_name, Swindow_name, (repv win), rep_Subr1) /*
 ::doc:sawfish.wm.windows.subrs#window-name::
 window-name WINDOW
@@ -1292,7 +1346,7 @@ description of HOOK-TYPE.
     rep_PUSHGC(gc_hook, hook);
     rep_PUSHGC(gc_args, args);
     rep_PUSHGC(gc_type, type);
-    tem = Fwindow_get (win, hook);
+    tem = Fwindow_get (win, hook, Qnil);
     if (tem && tem != Qnil)
     {
 	tem = Fcall_hook (tem, args, type);
@@ -1344,8 +1398,8 @@ WINDOW. Returns the symbol `nil' if no such image.
 	   int actual_format;
 	   long nitems, bytes_after;
 	   union {
-	       u_long *l;
-	       u_char *c;
+	       unsigned long *l;
+	       unsigned char *c;
 	   } data;
 
 	   static Atom kwm_win_icon = 0;
@@ -1357,7 +1411,7 @@ WINDOW. Returns the symbol `nil' if no such image.
 	   if (XGetWindowProperty (dpy, VWIN (win)->id, kwm_win_icon,
 				   0, 2, False, kwm_win_icon,
 				   &actual_type, &actual_format,
-				   &nitems, &bytes_after,
+				   (gpointer) &nitems, (gpointer) &bytes_after,
 				   &data.c) == Success
 	       && actual_type == kwm_win_icon
 	       && bytes_after == 0)
@@ -1591,6 +1645,8 @@ windows_init (void)
     rep_ADD_SUBR(Swindow_get);
     rep_ADD_SUBR(Smap_window_properties);
     rep_ADD_SUBR(Swindow_put);
+    rep_ADD_SUBR(Swindow_remprop);
+    rep_ADD_SUBR(Swindow_plist);
     rep_ADD_SUBR(Swindow_name);
     rep_ADD_SUBR(Swindow_full_name);
     rep_ADD_SUBR(Swindow_icon_name);
